@@ -19,6 +19,7 @@ import qualified Hasql.Postgres as HP
 import qualified Data.Scientific as Scientific
 import qualified Data.Vector as Vector
 import qualified PostgreSQLBinary.Encoder as PBE
+import qualified Data.Aeson as J
 
 
 type Text = Data.Text.Text
@@ -28,7 +29,11 @@ type LazyByteString = Data.ByteString.Lazy.ByteString
 type Scientific = Scientific.Scientific
 
 
-main = 
+main = do
+  version <-
+    fmap (fst . last . readP_to_S parseVersion . Data.Text.unpack) $
+    fmap (runIdentity . either (error . show) id) $
+    session1 $ H.tx Nothing $ H.singleEx [H.stmt| SHOW server_version |]
   hspec $ do
 
     describe "Feature" $ do
@@ -113,6 +118,14 @@ main =
 
     describe "Mapping of" $ do
 
+      when (version >= Version [9,2] []) $ describe "JSON" $ do
+
+        it "encodes and decodes" $ do
+          let v = (1, 'a') :: (Int, Char)
+              json = J.toJSON v
+              in flip shouldBe (Right (Identity json)) =<< do
+                   session1 $ H.tx Nothing $ H.singleEx [H.stmt| SELECT ($json :: json) |]
+
       describe "Enum" $ do
 
         it "casts text" $ do
